@@ -59,6 +59,7 @@ def main() -> int:
         return 0
 
     dbcli.update_last_open()
+    dbcli.execute('db.close()')
 
     print('\033[34mWelcome to CookieDB CLI!')
     print('See the complete CookieDB documentation at https://github.com/jaedsonpys/cookiedb')
@@ -67,7 +68,7 @@ def main() -> int:
 
     while True:
         try:
-            open_db = dbcli.execute('db.checkout()')
+            open_db = dbcli.execute('db.checkout()') or 'no open database'
             command = input(f'cookiedb ({open_db}) > ').strip()
 
             if command == 'exit':
